==> python-opensesame-3.3.8a1.tar.gz: python-opensesame-3.3.8a1/readme.md <==
# OpenSesame

![](opensesame_resources/theme/default/MokaSesame/32x32/misc/os-experiment.png)

OpenSesame is a tool to create experiments for psychology, neuroscience, and experimental economics.

Copyright, 2010-2021, Sebastiaan Mathôt and contributors.

<http://osdoc.cogsci.nl/>

[![Build Status](https://travis-ci.org/smathot/OpenSesame.svg?branch=ising)](https://travis-ci.org/smathot/OpenSesame)

## Features

- __A comprehensive graphical user interface__--flexible and easy-to-use
- __Support for Python scripting__--add the power of Python to your experiment
- __Support for external devices__--use your eye tracker, button box, EEG equipment, etc.
- __Free and open source__--released under the GPL3
- __Crossplatform__--runs on Windows, Mac OS, Linux, and Android (runtime only)

## Branches

Each major version of OpenSesame lives in its own branch. The master branch contains the latest stable version.

- `gibson` - 2.8
- `heisenberg` - 2.9
- `ising` - 3.0
- `james` - 3.1
- `kuhn` - 3.2
- `loewenfeld` - 3.3

## About

OpenSesame is a graphical experiment builder. OpenSesame provides an easy to use, point-and-click interface for creating psychological/ neuroscientific experiments.

## Citation

Mathôt, S., Schreij, D., & Theeuwes, J. (2012). OpenSesame: An open-source, graphical experiment builder for the social sciences. *Behavior Research Methods*, *44*(2), 314-324. [doi:10.3758/s13428-011-0168-7](http://dx.doi.org/doi:10.3758/s13428-011-0168-7)

## Contribute

If you wish to contribute to OpenSesame (and you are welcome to!), please visit:

- <http://osdoc.cogsci.nl/dev/howtocontribute/>

## License

OpenSesame is distributed under the terms of the GNU General Public License 3. The full license should be included in the file `COPYING`, or can be obtained from:

- <http://www.gnu.org/licenses/gpl.txt>

OpenSesame contains works of others. For the full license information, please refer to `debian/copyright`.

## Documentation

Installation instructions and documentation are available on the documentation website ...

- <http://osdoc.cogsci.nl/>

... which is itself also hosted on GitHub:

- <https://github.com/smathot/osdoc>

==> python-opensesame-3.3.11a1.tar.gz: python-opensesame-3.3.11a1/readme.md <==
# OpenSesame

![](https://github.com/open-cogsci/OpenSesame/raw/loewenfeld/opensesame_resources/einstein.png)

OpenSesame is a tool to create experiments for psychology, neuroscience, and experimental economics.

Copyright, 2010-2021, Sebastiaan Mathôt and contributors.

<http://osdoc.cogsci.nl/>

[![Build Status](https://travis-ci.org/smathot/OpenSesame.svg?branch=ising)](https://travis-ci.org/smathot/OpenSesame)

## Features

- A user-friendly interface — a modern, professional, and easy-to-use graphical interface
- Online experiments — run your experiment in a browser with OSWeb
- Python — add the power of Python to your experiment
- JavaScript — add the power of JavaScript to your experiment
- Use your devices — use your eye tracker, button box, EEG equipment, and more.
- Free — released under the GPL3
- Crossplatform — Windows, Mac OS, and Linux


## Branches

Each major version of OpenSesame lives in its own branch. The default branch is currently `loewenfeld`.

- `gibson` - 2.8
- `heisenberg` - 2.9
- `ising` - 3.0
- `james` - 3.1
- `kuhn` - 3.2
- `loewenfeld` - 3.3


## About

OpenSesame is a graphical experiment builder. OpenSesame provides an easy to use, point-and-click interface for creating psychological/ neuroscientific experiments.


## Citation

Mathôt, S., Schreij, D., & Theeuwes, J. (2012). OpenSesame: An open-source, graphical experiment builder for the social sciences. *Behavior Research Methods*, *44*(2), 314-324. [doi:10.3758/s13428-011-0168-7](http://dx.doi.org/doi:10.3758/s13428-011-0168-7)


## License

OpenSesame is distributed under the terms of the GNU General Public License 3. The full license should be included in the file `COPYING`, or can be obtained from:

- <http://www.gnu.org/licenses/gpl.txt>

OpenSesame contains works of others. For the full license information, please refer to `debian/copyright`.


## Documentation

Installation instructions and documentation are available on the documentation website ...

- <http://osdoc.cogsci.nl/>

... which is itself also hosted on GitHub:

- <https://github.com/smathot/osdoc>
